# stella-rs
High-performance phylogenetic analysis extensions for Cassiopeia lineage tracing, implemented in Rust with Python bindings.

It makes use of phylo-rs [S Vijendran · 2025](https://bmcbioinformatics.biomedcentral.com/articles/10.1186/s12859-025-06234-w).



